@@ -10,13 +10,13 @@
 /* .Fortran calls */
 
 extern void F77_NAME(datasimulation_f)(int *n, int *anum, int *num, int *observednum, double *observedepi,
-                                     double *tmax, int *temp, double *suspar, int *nsuspar, double *powersus,
+                                     double *tmax, double *suspar, int *nsuspar, double *powersus,
                                      double *transpar, int *ntranspar, double *powertrans, double *kernelpar, double *spark,
                                      double *delta1, double *delta2, double *suscov, double *transcov, double *cc, double *d3,
                                      double *epidat);
 
 extern void F77_NAME(datasimulationsinr_f)(int *n, int *anum, int *num, int *observednum,
-                                         double *observedepi, double *tmax, int *temp, double *suspar, int *nsuspar, double *powersus,
+                                         double *observedepi, double *tmax, double *suspar, int *nsuspar, double *powersus,
                                          double *transpar, int *ntranspar, double *powertrans, double *kernelpar,
                                          double *spark, double *gamma, double *deltain1, double *deltain2, double *deltanr1,
                                          double *deltanr2, double *suscov, double *transcov, double *cc, double *d3, double *epidat);
@@ -34,7 +34,7 @@ extern void F77_NAME(loglikcontilm_f)(int *n, int *ninfected, int *num, int *nsu
                                     double *spark, double *deltain1, double *deltain2, double *likk);
 
 
-extern void F77_NAME(mcmcsinr_f)(int *n, int *nsim, int *ni, int *temp, int *num, int *anum2, int *nsuspar,
+extern void F77_NAME(mcmcsinr_f)(int *n, int *nsim, int *ni, int *num, int *anum2, int *nsuspar,
     int *ntranspar, double *net, double *dis, double *epidat, int *blockupdate, int *priordistsuspar,
     int *priordisttranspar, int *priordistkernelparpar, int *priordistpowersus, int *priordistpowertrans,
     int *priordistsparkpar, int *priordistgammapar, double *suspar, double *suscov, double *powersus,
@@ -50,7 +50,7 @@ extern void F77_NAME(mcmcsinr_f)(int *n, int *nsim, int *ni, int *temp, int *num
     double *transparop, double *powertransparop, double *kernelparop, double *sparkop, double *gammaop,
     double *deltain2op, double *deltanr2op, double *epidatmctim, double *epidatmcrem, double *loglik);
 
-extern void F77_NAME(mcmcsir_f)(int *n, int *nsim, int *ni, int *num, int *anum2, int *temp, int *nsuspar,
+extern void F77_NAME(mcmcsir_f)(int *n, int *nsim, int *ni, int *num, int *anum2, int *nsuspar,
    int *ntranspar, double *net, double *dis, double *epidat, int *blockupdate,
    int *priordistsuspar, int *priordisttranspar, int *priordistkernelparpar, int *priordistsparkpar,
    int *priordistpowersus, int *priordistpowertrans, double *suspar, double *suscov,
@@ -70,13 +70,33 @@ void F77_SUB(infinity_value)(double *infval){
     *infval = R_PosInf;
 }
 
+void F77_SUB(seedin)(void)
+{
+   GetRNGstate();
+}
+
+
+void F77_SUB(seedout)(void)
+{
+   PutRNGstate();
+}
+
+
+void F77_SUB(randomnumber)(double *x)
+{
+        *x = unif_rand();
+}
+
+
+
+
 static const R_FortranMethodDef FortranEntries[] = {
-    {"datasimulation_f",      (DL_FUNC) &F77_NAME(datasimulation_f),        22},
-    {"datasimulationsinr_f",  (DL_FUNC) &F77_NAME(datasimulationsinr_f),    25},
+    {"datasimulation_f",      (DL_FUNC) &F77_NAME(datasimulation_f),        21},
+    {"datasimulationsinr_f",  (DL_FUNC) &F77_NAME(datasimulationsinr_f),    24},
     {"loglikcontilmsinr_f",   (DL_FUNC) &F77_NAME(loglikcontilmsinr_f),     22},
     {"loglikcontilm_f",       (DL_FUNC) &F77_NAME(loglikcontilm_f),         19},
-    {"mcmcsir_f",             (DL_FUNC) &F77_NAME(mcmcsir_f),               55},
-    {"mcmcsinr_f",            (DL_FUNC) &F77_NAME(mcmcsinr_f),              64},
+    {"mcmcsir_f",             (DL_FUNC) &F77_NAME(mcmcsir_f),               54},
+    {"mcmcsinr_f",            (DL_FUNC) &F77_NAME(mcmcsinr_f),              63},
     {NULL, NULL, 0}
 };
 
